part of masamune;

extension TextEditingControllerExtensions on TextEditingController? {
  bool get isEmpty {
    if (this == null) {
      return true;
    }
    return this!.text.isEmpty;
  }

  bool get isNotEmpty {
    if (this == null) {
      return false;
    }
    return this!.text.isNotEmpty;
  }
}

extension ButtonStyleExtension on ButtonStyle {
  ButtonStyle addState({
    Color? backgroundColor,
    Color? foregroundColor,
    Set<MaterialState> state = const {
      MaterialState.focused,
      MaterialState.hovered,
      MaterialState.pressed,
      MaterialState.selected,
    },
  }) {
    return copyWith(
      backgroundColor: MaterialStateProperty.resolveWith((st) {
        if (st.containsAny(state)) {
          return backgroundColor ?? this.backgroundColor?.resolve(st);
        }
        return this.backgroundColor?.resolve(st);
      }),
      foregroundColor: MaterialStateProperty.resolveWith((st) {
        if (st.containsAny(state)) {
          return foregroundColor ?? this.foregroundColor?.resolve(st);
        }
        return this.foregroundColor?.resolve(st);
      }),
    );
  }
}

extension PlatformBuildContextExtensions on BuildContext {
  bool isMobile({
    double thresholdWidth = kPlatformThreshold,
  }) {
    if (Config.isAndroid || Config.isIOS) {
      return true;
    }
    final width = mediaQuery.size.width;
    if (width < thresholdWidth) {
      return true;
    }
    return false;
  }

  bool get isModal {
    return ModalRoute.of(this) is UIModalRoute;
  }

  bool isMobileOrModal({
    double thresholdWidth = kPlatformThreshold,
  }) {
    if (isModal) {
      return true;
    }
    return isMobile(thresholdWidth: thresholdWidth);
  }

  bool get isFullscreen {
    final parentRoute = ModalRoute.of(this);
    return parentRoute is PageRoute<dynamic> && parentRoute.fullscreenDialog;
  }

  RouteQuery get fullscreenOrModalRouteQuery {
    if (isMobile()) {
      return RouteQuery.fullscreen;
    } else {
      return RouteQuery.modal;
    }
  }
}
